var fs = require('fs');
var sk = require('./lib/index');
var crypto = require('crypto');

var sshf = require('ssh-fingerprint');
var httpsig = require('http-signature');

var keyPem = fs.readFileSync('foo');
var keySsh = fs.readFileSync('foo.pub');

var Benchmark = require('benchmark');

var key = sk.Key.parse(keyPem, 'pem', './foo.pem');

console.log('-> using a %d bit %s key', key.size, key.type);
console.log('-> fingerprint: %s', key.fingerprint('sha256').toString());

var fp = sk.Fingerprint.parse('MD5:0a:b6:37:a4:5f:e7:94:d3:31:e4:72:91:fc:0c:bb:2f');

var keySshString = keySsh.toString();
var keyPemString = keyPem.toString();

var suite = new Benchmark.Suite();
suite.add('Key.parse(pem)', function() {
	sk.Key.parse(keyPem, 'pem');
});
suite.add('Key.parse(ssh)', function() {
	sk.Key.parse(keySsh, 'ssh');
});
suite.add('Key#fingerprint(md5).toString', function() {
	key.fingerprint('md5').toString();
});
suite.add('Key.parse(ssh)#fingerprint(md5).toString', function() {
	var k = sk.Key.parse(keySsh, 'ssh');
	k.fingerprint('md5').toString();
});
suite.add('Fingerprint.parse', function() {
	sk.Fingerprint.parse('MD5:0a:b6:37:a4:5f:e7:94:d3:31:e4:72:91:fc:0c:bb:2f');
});
suite.add('Fingerprint#matches(Key)', function() {
	fp.matches(key);
});
suite.add('Key#toBuffer(pem)', function() {
	key.toBuffer('pem');
});
suite.add('Key#toBuffer(ssh)', function() {
	key.toBuffer('ssh');
});
suite.add('ssh-fingerprint(md5)', function() {
	sshf.calculate(keySshString, {algorithm: 'md5'});
});
suite.add('node-http-sig.pemToRsaSSHKey', function() {
	httpsig.pemToRsaSSHKey(keyPemString, 'foo@foo.com');
});
suite.add('node-http-sig.sshKeyFingerprint', function() {
	httpsig.sshKeyFingerprint(keySshString);
});

suite.on('cycle', function(evt) {
	console.log(String(evt.target));
});

suite.run({async: true});
